==> ThbgmExtractor-1.6.4.tar.bz2: ThbgmExtractor-1.6.4/core/Smdn.Windows.Forms.ThbgmPlayer/Smdn.Windows.Forms.ThbgmPlayer/ProductSelector.Designer.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2009-2014 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

namespace Smdn.Windows.Forms.ThbgmPlayer {
  partial class ProductSelector {
    /// <summary> 
    /// 必要なデザイナ変数です。
    /// </summary>
    private System.ComponentModel.IContainer components = null;

    /// <summary> 
    /// 使用中のリソースをすべてクリーンアップします。
    /// </summary>
    /// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
    protected override void Dispose(bool disposing)
    {
      if (disposing && (components != null)) {
        components.Dispose();
      }
      base.Dispose(disposing);
    }

    #region コンポーネント デザイナで生成されたコード

    /// <summary> 
    /// デザイナ サポートに必要なメソッドです。このメソッドの内容を 
    /// コード エディタで変更しないでください。
    /// </summary>
    private void InitializeComponent()
    {
      System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(ProductSelector));
      this.label1 = new System.Windows.Forms.Label();
      this.label2 = new System.Windows.Forms.Label();
      this.buttonChangeBgmSourcePath = new System.Windows.Forms.Button();
      this.productInfoDropDownList = new Smdn.Windows.Forms.ThbgmPlayer.ProductInfoDropDownList();
      this.textBoxBgmSourcePath = new System.Windows.Forms.TextBox();
      this.SuspendLayout();
      // 
      // label1
      // 
      this.label1.AccessibleDescription = null;
      this.label1.AccessibleName = null;
      resources.ApplyResources(this.label1, "label1");
      this.label1.Font = null;
      this.label1.Name = "label1";
      // 
      // label2
      // 
      this.label2.AccessibleDescription = null;
      this.label2.AccessibleName = null;
      resources.ApplyResources(this.label2, "label2");
      this.label2.Font = null;
      this.label2.Name = "label2";
      // 
      // buttonChangeBgmSourcePath
      // 
      this.buttonChangeBgmSourcePath.AccessibleDescription = null;
      this.buttonChangeBgmSourcePath.AccessibleName = null;
      resources.ApplyResources(this.buttonChangeBgmSourcePath, "buttonChangeBgmSourcePath");
      this.buttonChangeBgmSourcePath.BackgroundImage = null;
      this.buttonChangeBgmSourcePath.Font = null;
      this.buttonChangeBgmSourcePath.Name = "buttonChangeBgmSourcePath";
      // 
      // productInfoDropDownList
      // 
      this.productInfoDropDownList.AccessibleDescription = null;
      this.productInfoDropDownList.AccessibleName = null;
      resources.ApplyResources(this.productInfoDropDownList, "productInfoDropDownList");
      this.productInfoDropDownList.BackgroundImage = null;
      this.productInfoDropDownList.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
      this.productInfoDropDownList.Font = null;
      this.productInfoDropDownList.FormattingEnabled = true;
      this.productInfoDropDownList.Name = "productInfoDropDownList";
      this.productInfoDropDownList.SelectedItem = null;
      // 
      // textBoxBgmSourcePath
      // 
      this.textBoxBgmSourcePath.AccessibleDescription = null;
      this.textBoxBgmSourcePath.AccessibleName = null;
      resources.ApplyResources(this.textBoxBgmSourcePath, "textBoxBgmSourcePath");
      this.textBoxBgmSourcePath.BackgroundImage = null;
      this.textBoxBgmSourcePath.Font = null;
      this.textBoxBgmSourcePath.Name = "textBoxBgmSourcePath";
      // 
      // ProductSelector
      // 
      this.AccessibleDescription = null;
      this.AccessibleName = null;
      this.AllowDrop = true;
      resources.ApplyResources(this, "$this");
      this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
      this.BackgroundImage = null;
      this.Controls.Add(this.label1);
      this.Controls.Add(this.label2);
      this.Controls.Add(this.buttonChangeBgmSourcePath);
      this.Controls.Add(this.productInfoDropDownList);
      this.Controls.Add(this.textBoxBgmSourcePath);
      this.Font = null;
      this.Name = "ProductSelector";
      this.ResumeLayout(false);
      this.PerformLayout();

    }

    #endregion

    private System.Windows.Forms.Label label1;
    private System.Windows.Forms.Label label2;
    private System.Windows.Forms.Button buttonChangeBgmSourcePath;
    private Smdn.Windows.Forms.ThbgmPlayer.ProductInfoDropDownList productInfoDropDownList;
    private System.Windows.Forms.TextBox textBoxBgmSourcePath;
  }
}

==> ThbgmExtractor-1.6.6.tar.bz2: ThbgmExtractor-1.6.6/core/Smdn.Windows.Forms.ThbgmPlayer/Smdn.Windows.Forms.ThbgmPlayer/ProductSelector.Designer.cs <==
// 
// Author:
//       smdn <smdn@smdn.jp>
// 
// Copyright (c) 2009-2019 smdn
// 
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to deal
// in the Software without restriction, including without limitation the rights
// to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
// copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
// 
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
// 
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
// AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
// THE SOFTWARE.

namespace Smdn.Windows.Forms.ThbgmPlayer {
  partial class ProductSelector {
    /// <summary> 
    /// 必要なデザイナ変数です。
    /// </summary>
    private System.ComponentModel.IContainer components = null;

    /// <summary> 
    /// 使用中のリソースをすべてクリーンアップします。
    /// </summary>
    /// <param name="disposing">マネージ リソースが破棄される場合 true、破棄されない場合は false です。</param>
    protected override void Dispose(bool disposing)
    {
      if (disposing && (components != null)) {
        components.Dispose();
      }
      base.Dispose(disposing);
    }

    #region コンポーネント デザイナで生成されたコード

    /// <summary> 
    /// デザイナ サポートに必要なメソッドです。このメソッドの内容を 
    /// コード エディタで変更しないでください。
    /// </summary>
    private void InitializeComponent()
    {
      System.ComponentModel.ComponentResourceManager resources = new System.ComponentModel.ComponentResourceManager(typeof(ProductSelector));
      this.label1 = new System.Windows.Forms.Label();
      this.label2 = new System.Windows.Forms.Label();
      this.buttonChangeBgmSourcePath = new System.Windows.Forms.Button();
      this.productInfoDropDownList = new Smdn.Windows.Forms.ThbgmPlayer.ProductInfoDropDownList();
      this.textBoxBgmSourcePath = new System.Windows.Forms.TextBox();
      this.tableLayoutPanelMain = new System.Windows.Forms.TableLayoutPanel();
      this.panelBgmSource = new System.Windows.Forms.Panel();
      this.tableLayoutPanelMain.SuspendLayout();
      this.panelBgmSource.SuspendLayout();
      this.SuspendLayout();
      // 
      // label1
      // 
      resources.ApplyResources(this.label1, "label1");
      this.label1.Name = "label1";
      // 
      // label2
      // 
      resources.ApplyResources(this.label2, "label2");
      this.label2.Name = "label2";
      // 
      // buttonChangeBgmSourcePath
      // 
      resources.ApplyResources(this.buttonChangeBgmSourcePath, "buttonChangeBgmSourcePath");
      this.buttonChangeBgmSourcePath.Name = "buttonChangeBgmSourcePath";
      // 
      // productInfoDropDownList
      // 
      resources.ApplyResources(this.productInfoDropDownList, "productInfoDropDownList");
      this.productInfoDropDownList.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
      this.productInfoDropDownList.FormattingEnabled = true;
      this.productInfoDropDownList.Name = "productInfoDropDownList";
      this.productInfoDropDownList.SelectedItem = null;
      // 
      // textBoxBgmSourcePath
      // 
      resources.ApplyResources(this.textBoxBgmSourcePath, "textBoxBgmSourcePath");
      this.textBoxBgmSourcePath.Name = "textBoxBgmSourcePath";
      // 
      // tableLayoutPanelMain
      // 
      resources.ApplyResources(this.tableLayoutPanelMain, "tableLayoutPanelMain");
      this.tableLayoutPanelMain.Controls.Add(this.panelBgmSource, 1, 1);
      this.tableLayoutPanelMain.Controls.Add(this.label1, 0, 0);
      this.tableLayoutPanelMain.Controls.Add(this.label2, 0, 1);
      this.tableLayoutPanelMain.Controls.Add(this.productInfoDropDownList, 1, 0);
      this.tableLayoutPanelMain.Name = "tableLayoutPanelMain";
      // 
      // panelBgmSource
      // 
      this.panelBgmSource.Controls.Add(this.textBoxBgmSourcePath);
      this.panelBgmSource.Controls.Add(this.buttonChangeBgmSourcePath);
      resources.ApplyResources(this.panelBgmSource, "panelBgmSource");
      this.panelBgmSource.Name = "panelBgmSource";
      // 
      // ProductSelector
      // 
      this.AllowDrop = true;
      resources.ApplyResources(this, "$this");
      this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
      this.Controls.Add(this.tableLayoutPanelMain);
      this.Name = "ProductSelector";
      this.tableLayoutPanelMain.ResumeLayout(false);
      this.panelBgmSource.ResumeLayout(false);
      this.panelBgmSource.PerformLayout();
      this.ResumeLayout(false);

    }

    #endregion

    private System.Windows.Forms.Label label1;
    private System.Windows.Forms.Label label2;
    private System.Windows.Forms.Button buttonChangeBgmSourcePath;
    private Smdn.Windows.Forms.ThbgmPlayer.ProductInfoDropDownList productInfoDropDownList;
    private System.Windows.Forms.TextBox textBoxBgmSourcePath;
    private System.Windows.Forms.TableLayoutPanel tableLayoutPanelMain;
    private System.Windows.Forms.Panel panelBgmSource;
  }
}
